% ---------------------------------------------------------------------------
% discrete_AR.m: creates the transition matrix to approximate a continuous AR
% process by a discrete state-space one (following Tauchen (1986))
% y_{t+1} = rho*y_t + epsilon_t 
% with epsilon_t~N(0,sigma2*(1-rho^2))
% 

function [y,p] = discrete_AR(n,rho,sigma2,ml,mh)
% take a grid between [-ml*stddev;mh*stddev]
if nargin==4
    mh=ml;
end

if n==1
    p=1;
    y=0;
else
    y = linspace(-ml*sqrt(sigma2),mh*sqrt(sigma2),n);
    p = zeros(n,n);
    w = y(2)-y(1);
    for i=1:n
        
        p(i,1) = normcdf((y(1)-rho*y(i)+w/2)/sqrt(sigma2*(1-rho^2)));
        p(i,n) = 1-normcdf((y(n)-rho*y(i)-w/2)/sqrt(sigma2*(1-rho^2)));       
        p(i,2:n-1) = normcdf((y(2:n-1)-rho*y(i)+w/2)/sqrt(sigma2*(1-rho^2)))-normcdf((y(2:n-1)-rho*y(i)-w/2)/sqrt(sigma2*(1-rho^2)));
    end    
end

