% =======================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% distdyn(u0,g0,y): computes the evolution of employment distribution 
% and other labor market variables for one period, starting in (u0,g0)
% after shock y hits in the DMP model
%
% Instructions: - u0 initial unemployment rate
% - g0 initial employment distribution across z's
% - y productivity shock (index)
% =======================================

function [u1,g1,outpp,v,theta,ue,eu,hi,sp,lf,output,error] = distdyn(u0,g0,y)
global tmat
global lambda_u
global pi_z
global nz
global y_grid
global z_grid
global delta
global gz
global A

error=false;

pvect=p(tmat);

u1=u0*(1-lambda_u*pvect(y));
g1=zeros(nz,1);
sp=0;
lf=0;

output=0;

for z0=1:nz
    for z1=1:nz  
             g1(z1)=g1(z1)+(1-delta)*g0(z0)*pi_z(z0,z1);
             output=output+(1-delta)*g0(z0)*pi_z(z0,z1)*A*(exp(y_grid(y))+z_grid(z1));
     end
end

sp=delta*(1-u0);
lf=delta*(1-u0);

u1=u1+sp;

hi=u0*lambda_u*pvect(y); %hi is hires of unemployed
v=u0*tmat(y);
theta=tmat(y);

gzprime=gz;
g1=g1+gzprime*hi;
output=output+hi*sum(A*(exp(y_grid(y))+z_grid(:)).*gzprime);
outpp=output/(1-u1); %return total output per person

ue=lambda_u*pvect(y); %job finding rate of unemployed
eu=sp/((1-u0)*(1-ue/2)); %job separation rate following Shimer's method



