% =======================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% solve.m: solves the standard DMP model 
%
% Instructions: simply run 'solve()'
% =======================================

global delta
global beta
global b
global thetamax
global c
global lambda_u
global gamma 
global m
global A
global mu   %bargaining power of workers

global ymax
global ymin
global ny
global y_grid
global pi_y

global zmax
global zmin
global nz
global z_grid
global pi_z
global gz
global sigma_z
global rho_z



% --------------------
% Load parameters
%

parameters;

% ------------------------
% Declaration of solutions
%

global U
global gtau
global tmat

% Initial conditions for the joint surplus
if ~exist('S1')
    global S1
    S1 = zeros(ny,nz);
    mean_y = (ymin+ymax)/2;
    mean_z = (zmin+zmax)/2;
    
    for i=1:ny
        for j=1:nz                      
           S1(i,j) = (1-b)/(1-beta*(1-delta-mu*.45));
        end
    end    
end

S0 = 1e3*ones(ny,nz);
Stmp = zeros(ny,nz);
gtau = zeros(ny,nz); %optimal policy for tau

% --------------------
% Main iteration on S
%


[My_id,Mz_id]=ndgrid(1:ny,1:nz);

counter=0;

while(sum(reshape((S1-S0).^2,ny*nz,1))>CV_tol)
    
    S0=S1;
    tmat = solvetheta(S0);
    
    gzprime=gz'; %need to do that in case ny=1
    gzprime=gzprime(Mz_id);
    MS=sum(S0.*gzprime,2);
    Stmp = (1-delta)*S0 - mu*p(tmat(My_id)).*MS(My_id);  
       
    S1(:,:) = A*exp(y_grid(My_id)'+z_grid(Mz_id))-b+beta*pi_y*Stmp(:,:)*pi_z'; % pi_y*Stmp*pi_z' computes expectation
    
    
    counter=counter+1;
    if(mod(counter,10)==0)
        fprintf('Iteration No.%d - CV=%d\n',counter,sum(reshape((S1-S0).^2,ny*nz,1))/(ny*nz));
    end
end

% now, compute the value of unemployment
U = solveU(tmat,S1);






