% =======================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% solveU(tmat,S).m: find the fixed point for unemployment valuation U(y)
% given 'tmat' matrix of tightness in DMP model
%
% Instructions: -tmat: nyx1 vector of tightnesses
% - S is the surplus computed by solve.m (ny x nz matrix)
% =======================================

function [U1] = solveU(tmat,S)
global beta
global b
global pi_y
global lambda_u
global ny
global mu
global nz
global gz

CV_tol = 1e-3; % tolerance for convergence
U0 = ones(ny,1); % initialize vector of U(y) (put 1 to enter loop)
U1 = zeros(ny,1);

counter=0;

[My_id,Mz_id] = ndgrid(1:ny,1:nz);

gzprime=gz';
gzprime=gzprime(Mz_id);
expected_surplus=sum(S.*gzprime,2);
R=mu*p(tmat).*expected_surplus;

while norm(U1-U0)>CV_tol %&& counter
    U0=U1;
    
    U1 = b + beta*pi_y*(U0+lambda_u*R); % compute expectation Ui = b+beta(sum pi_ij*Uj)
    counter=counter+1;
end



