% =======================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% stats(): compute and display standard business cycle statistics
% for DMP model
%
% Instructions: simply run 'stats()'
% =======================================


[u1,g1]=findss(ceil(ny/2)); % find ss when y is constant equal to mean
rng(0,'twister');
T=5000; %simulate the model for T quarters

HP_param=1e5;

lag=4;

y=zeros((T+lag)*3,1);
unemp=zeros((T+lag)*3,1);
output=zeros((T+lag)*3,1);
outpp=zeros((T+lag)*3,1);
theta=zeros((T+lag)*3,1);
v=zeros((T+lag)*3,1);
hi=zeros((T+lag)*3,1);
lf=zeros((T+lag)*3,1);

y1=ceil(ny/2);

for i=1:(T+lag)*3 %simulate model in month
    g0=g1;
    u0=u1;
    y0=y1;
    
    y1=markov_inv(pi_y,y0,rand());
    y(i)=y1;
    
    [u1,g1,outpp(i),v(i),theta(i),~,~,hi(i),~,lf(i),output(i),error] = distdyn(u0,g0,y1);
    if(error==true)
        fprintf('stats.m: no entry at t=%d\n',i);
    end
    unemp(i)=u1;
           
    if(mod(i,20)==0)
        fprintf('Step No.%d\n',i);
    end     
end

y=y(lag*3+1:(lag+T)*3);
unemp=unemp(lag*3+1:(lag+T)*3);
outpp=outpp(lag*3+1:(lag+T)*3);
output=output(lag*3+1:(lag+T)*3);
v=v(lag*3+1:(lag+T)*3);
theta=theta(lag*3+1:(lag+T)*3);
hi=hi(lag*3+1:(lag+T)*3);
lf=lf(lag*3+1:(lag+T)*3);


y_q=zeros(T,1);
unemp_q=zeros(T,1);
outpp_q=zeros(T,1);
output_q=zeros(T,1);
theta_q=zeros(T,1);
v_q=zeros(T,1);
hi_q=zeros(T,1);
lf_q=zeros(T,1);

for i=1:T % aggregate in quarterly data
    y_q(i) = sum(y((i-1)*3 + (1:3)))/3;
    unemp_q(i) = sum(unemp((i-1)*3 + (1:3)))/3;
    outpp_q(i) = sum(outpp((i-1)*3 + (1:3)))/3;
    output_q(i) = sum(output((i-1)*3 + (1:3)));
    v_q(i) = sum(v((i-1)*3 + (1:3)))/3;
    theta_q(i) = sum(theta((i-1)*3 + (1:3)))/3;
    hi_q(i) = sum(hi((i-1)*3 + (1:3)));
    lf_q(i) = sum(lf((i-1)*3 + (1:3)));
end



% output per person

outpp_t = hpfilter(outpp_q,HP_param);
logoutpp_dev = log(outpp_q) - log(outpp_t); 
output_t = hpfilter(output_q,HP_param); 
logoutput_dev = log(output_q) - log(output_t);



% u, v, theta

unemp_t = hpfilter(unemp_q,HP_param); % t for trend
logunemp_dev = log(unemp_q) - log(unemp_t); % log deviation from trend

v_t = hpfilter(v_q,HP_param); 
logv_dev = log(v_q) - log(v_t);

theta_t = hpfilter(theta_q,HP_param); 
logtheta_dev = log(theta_q) - log(theta_t);


% labor mkt flows

hi_t = hpfilter(hi_q,HP_param); 
loghi_dev = log(hi_q) - log(hi_t);

lf_t = hpfilter(lf_q,HP_param); 
loglf_dev = log(lf_q) - log(lf_t);


% compute empirical correlation

cov=0;
for i=1:T    
    x = [logoutput_dev(i);logoutpp_dev(i);logunemp_dev(i);logv_dev(i);loghi_dev(i);loglf_dev(i)];
    cov = cov + x*x'/(T-1);    
end

N=length(x);
stdev=zeros(1,N);
cor=zeros(N,N);
for i=1:N;
    stdev(i)=sqrt(cov(i,i));
    for j=1:N
        cor(i,j)=cov(i,j)/sqrt(cov(i,i)*cov(j,j));
    end
end

autocor=0;
xlag=[logoutput_dev(1);logoutpp_dev(1);logunemp_dev(1);logv_dev(1);loghi_dev(1);loglf_dev(1)];
for i=2:T    
    x = [logoutput_dev(i);logoutpp_dev(i);logunemp_dev(i);logv_dev(i);loghi_dev(i);loglf_dev(i)];
    autocor = autocor + x.*xlag;   
    xlag=x;
end
autocor=autocor'./((T-1)*stdev.^2);

format short
fprintf('--------------------------------------------------------------\n');
fprintf('Summary of the statistics (stdev(log), autocor(log), cor(log))\n');
fprintf('--------------------------------------------------------------\n');
fprintf('       (1)       (2)       (3)       (4)       (5)       (6)\n');
fprintf('    output      p(t)         u         v        hi        lf\n');
disp(stdev);
disp(autocor);
fprintf('--------------------------------------------------------------\n');
disp(cor);
fprintf('--------------------------------------------------------------\n');


