% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% create_gz (param,vars): 
% computes the stationary distribution of z for s constant to its mean.
%
% Instructions: - 'param' is a structure of parameters for the model
% - 'vars' is a structure of variables created by 'initialize_vars(param)'
%
% ========================================================================

% -------------------------------------------------------------------------
% create_gz.m : computes stationary distribution of z given sigma
% 
function [gz,mu,var,autocor]= create_gz(param,vars)

% Compute the invariant distribution of z for s in
% the middle of the grid.


I=eye(param.nz);
m_ysz=reshape(vars.pi_ysz(:),param.ny,param.ns,param.nz,param.ny,param.ns,param.nz);
mat_z = reshape(squeeze(sum(sum(m_ysz(1,ceil(param.ns/2),:,:,:,:),4),5)),param.nz,param.nz);
phi=null(mat_z'-I); %compute stationary distribution of (y,s,z)
phi=phi(:,1); % retrieve the first solution
gz=phi/sum(phi); % normalize


mu=gz'*vars.z_grid;
var=gz'*(vars.z_grid-mu).^2;
autocov=0;

for i=1:param.nz
   for j=1:param.nz
         autocov=autocov+phi(i)*mat_z(i,j)*(vars.z_grid(i)-mu)*(vars.z_grid(j)-mu);
   end
end
autocor=autocov/var;





