% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% create_ys_mat (param,vars): creates the transition matrix to compute 
% expectations with respect to (y,sigma_z)
%
% Convention: pi_ys(i,j) is P[ (y,s)_{t+1} = j | (y,s)_t = i] where i is
% the flat index corresponding to i=(y-1)*ny+s
%
% Instructions: - 'param' is a structure of parameters for the model
% - 'vars' is a structure of variables created by 'initialize_vars(param)'
%
% ========================================================================

function [ys_mat] = create_ys_mat(param,vars)

[My0_id,Ms0_id,My1_id,Ms1_id]=ndgrid(1:param.ny,1:param.ns,1:param.ny,1:param.ns);
cov_ey_es=param.cor_ys;

ys_mat = zeros(param.ny*param.ns,param.ny*param.ns);

ubound_y=inf*ones(param.ny,param.ns,param.ny,param.ns);
lbound_y=-inf*ones(param.ny,param.ns,param.ny,param.ns);
ubound_s=inf*ones(param.ny,param.ns,param.ny,param.ns);
lbound_s=-inf*ones(param.ny,param.ns,param.ny,param.ns);

if param.ny>1
    ubound_y(:,:,1:param.ny-1,:)=((vars.y_grid(My1_id(:,:,1:param.ny-1,:))+vars.y_grid(My1_id(:,:,2:param.ny,:)))/2-param.rho_y*vars.y_grid(My0_id(:,:,1:param.ny-1,:)))/sqrt(param.sigma_y^2*(1-param.rho_y^2));
    lbound_y(:,:,2:param.ny,:)=((vars.y_grid(My1_id(:,:,1:param.ny-1,:))+vars.y_grid(My1_id(:,:,2:param.ny,:)))/2-param.rho_y*vars.y_grid(My0_id(:,:,2:param.ny,:)))/sqrt(param.sigma_y^2*(1-param.rho_y^2));
end

if param.ns>1
    ubound_s(:,:,:,1:param.ns-1)=(log((vars.s_grid(Ms1_id(:,:,:,1:param.ns-1))+vars.s_grid(Ms1_id(:,:,:,2:param.ns)))/2)-param.rho_s*log(vars.s_grid(Ms0_id(:,:,:,1:param.ns-1)))-(1-param.rho_s)*log(param.sigma_z))/sqrt(param.sigma_s^2*(1-param.rho_s^2));
    lbound_s(:,:,:,2:param.ns)=(log((vars.s_grid(Ms1_id(:,:,:,1:param.ns-1))+vars.s_grid(Ms1_id(:,:,:,2:param.ns)))/2)-param.rho_s*log(vars.s_grid(Ms0_id(:,:,:,2:param.ns)))-(1-param.rho_s)*log(param.sigma_z))/sqrt(param.sigma_s^2*(1-param.rho_s^2));
end

ubound_y=reshape(ubound_y(:),param.ny*param.ns*param.ny*param.ns,1);
lbound_y=reshape(lbound_y(:),param.ny*param.ns*param.ny*param.ns,1);
ubound_s=reshape(ubound_s(:),param.ny*param.ns*param.ny*param.ns,1);
lbound_s=reshape(lbound_s(:),param.ny*param.ns*param.ny*param.ns,1);

ys_mat(:) = mvncdf([lbound_y lbound_s],[ubound_y ubound_s],[0 0],[1 cov_ey_es; cov_ey_es 1]);



