% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% create_ysz_mat (param,vars): creates the transition matrix to compute
% expectations with respect to (y,sigma_z,z), assumes create_ys_mat was
% called before (stored in vars)
%
% Instructions: - 'param' is a structure of parameters for the model
% - 'vars' is a structure of variables created by 'initialize_vars(param)'
%
% ========================================================================

function [ysz_mat] = create_ysz_mat(param,vars)

[My0_id,Ms0_id,Mz0_id,My1_id,Ms1_id,Mz1_id]=ndgrid(1:param.ny,1:param.ns,1:param.nz,1:param.ny,1:param.ns,1:param.nz);

ubound_z=inf*ones(param.ny,param.ns,param.nz,param.ny,param.ns,param.nz);
lbound_z=-inf*ones(param.ny,param.ns,param.nz,param.ny,param.ns,param.nz);

if param.nz>1
     ubound_z(:,:,:,:,:,1:param.nz-1)=((vars.z_grid(Mz1_id(:,:,:,:,:,1:param.nz-1))+vars.z_grid(Mz1_id(:,:,:,:,:,2:param.nz)))/2-param.rho_z*vars.z_grid(Mz0_id(:,:,:,:,:,1:param.nz-1)))./sqrt(vars.s_grid(Ms0_id(:,:,:,:,:,1:param.nz-1)).^2*(1-param.rho_z^2));
     lbound_z(:,:,:,:,:,2:param.nz)=((vars.z_grid(Mz1_id(:,:,:,:,:,1:param.nz-1))+vars.z_grid(Mz1_id(:,:,:,:,:,2:param.nz)))/2-param.rho_z*vars.z_grid(Mz0_id(:,:,:,:,:,1:param.nz-1)))./sqrt(vars.s_grid(Ms0_id(:,:,:,:,:,1:param.nz-1)).^2*(1-param.rho_z^2));    
end

ubound_z = reshape(ubound_z(:),param.ny*param.ns*param.nz,param.ny*param.ns*param.nz);
lbound_z = reshape(lbound_z(:),param.ny*param.ns*param.nz,param.ny*param.ns*param.nz);
My0_id=reshape(My0_id(:),param.ny*param.ns*param.nz,param.ny*param.ns*param.nz);
Ms0_id=reshape(Ms0_id(:),param.ny*param.ns*param.nz,param.ny*param.ns*param.nz);
My1_id=reshape(My1_id(:),param.ny*param.ns*param.nz,param.ny*param.ns*param.nz);
Ms1_id=reshape(Ms1_id(:),param.ny*param.ns*param.nz,param.ny*param.ns*param.nz);

ysz_mat = (normcdf(ubound_z)-normcdf(lbound_z)).*vars.pi_ys(My0_id+(Ms0_id-1)*param.ny + (My1_id-1)*param.ny*param.ns + (Ms1_id-1)*param.ny*param.ns*param.ny);

