% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% draw_ys (y0,s0,param,vars): draw a pseudo-random (y1,s1) given (y0,s0)
% according to 
%   y_1 = rho_y*y_0 + sigma_y*sqrt(1-rho_y^2)e_y1
%   log s_1 = (1-rho_s)log(sigma_z) + rho_s*log(s_0) + sigma_s*sqrt(1-rho_s^2)e_s1
% in which (e_y1,e_s1)~N([0 0], [1 cov_ey_es; cov_ey_es 1]) 
%
% Instructions: - (y0,s0) previous aggregate state of economy (in index)
% - 'param' is a structure of parameters for the model
% - 'vars' is a structure of variables created by 'initialize_vars(param)'
%
% ========================================================================


function [y1_id,s1_id] = draw_ys (y0_id,s0_id,param,vars)

Sigma = [1 param.cor_ys; param.cor_ys 1];
R = chol(Sigma);

e1=R'*randn(2,1);

y1=param.rho_y*vars.y_grid(y0_id)+param.sigma_y*sqrt(1-param.rho_y^2)*e1(1);
log_s1 = (1-param.rho_s)*log(param.sigma_z) + param.rho_s*log(vars.s_grid(s0_id))+param.sigma_s*sqrt(1-param.rho_s^2)*e1(2);
s1=exp(log_s1);

if param.ny==1
    y1_id=1;
else    
    y_separator=(vars.y_grid(1:param.ny-1)+vars.y_grid(2:param.ny))/2;
    Iy=find(y_separator <= y1);
    
    if isempty(Iy)
        y1_id=1;
    else
        y1_id=max(Iy)+1;
    end
end

if param.ns==1
    s1_id=1;
else
    s_separator=(vars.s_grid(1:param.ns-1)+vars.s_grid(2:param.ns))/2;
    Is=find(s_separator <= s1);
    
    if isempty(Is)
        s1_id=1;
    else
        s1_id=max(Is)+1;
    end
end

