% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% draw_ys_value (y0,s0,param,vars): draw a pseudo-random (y1,s1) given (y0,s0)
% according to 
%   y_1 = rho_y*y_0 + sigma_y*sqrt(1-rho_y^2)e_y1
%   log s_1 = (1-rho_s)log(sigma_z) + rho_s*log(s_0) + sigma_s*sqrt(1-rho_s^2)e_s1
% in which (e_y1,e_s1)~N([0 0], [1 cov_ey_es; cov_ey_es 1]) 
%
% Instructions: - (y0,s0) previous aggregate state of economy (in value)
% - 'param' is a structure of parameters for the model
% - 'vars' is a structure of variables created by 'initialize_vars(param)'
%
% ========================================================================

function [y1,s1] = draw_ys_value (y0,s0,param,vars)

Sigma = [1 param.cor_ys; param.cor_ys 1];
R = chol(Sigma);

e1=R'*randn(2,1);

y1=param.rho_y*y0+param.sigma_y*sqrt(1-param.rho_y^2)*e1(1);
log_s1 = (1-param.rho_s)*log(param.sigma_z) + param.rho_s*log(s0)+param.sigma_s*sqrt(1-param.rho_s^2)*e1(2);
s1=exp(log_s1);

y1=min(max(y1,vars.ymin),vars.ymax);
s1=min(max(s1,vars.smin),vars.smax);



