% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% empirics.m: script that computes standard business cycle statistics for
% the data.
%
% Usage: simply run 'empirics()'
%
% =======================================================================

close all

HP_PARAM = 'Q';

start_date=1972; % cover period from 1972Q1-2009Q4
end_date=2009; %included
end_date_q=2009.75;
end_date_m=2009+11/12;


% -------------------------------------
% Load and format empirical data

load data/MISC_DATA
load data/BED_DATA
load data/JOLTS_DATA
load data/BLOOM_DATA
load data/FRED_DATA
load data/CONS_DATA
load data/SHIMER_DATA

BED_start_date=1992.5;
BED_end_date=2009.75;
JOLTS_start_date=2001;
JOLTS_end_date=2009+11/12;

start_year=1972; %start 1972 Qtr1
end_year=2009;
nb_periods=4*(end_year-start_year) + 4; %end in end_year Qtr4

% load series

d_ue_q = NaN*ones(nb_periods,1);
d_eu_q = NaN*ones(nb_periods,1);

d_output_q = d_output((start_date-1947)*4+1:(end_date_q-1947)*4+1); %quarterly
d_outpp_q = d_outpp((start_date-1947)*4+1:(end_date_q-1947)*4+1); %quarterly
d_unemp = d_unemp(int32((start_date-1948)*12+1:(end_date_m-1948)*12+1)); %monthly
d_labforce = d_labforce(int32((start_date-1948)*12+1:(end_date_m-1948)*12+1)); %monthly
d_entry_q((BED_start_date-start_date)*4+1:(BED_end_date-start_date)*4+1,1) = BED_DATA2((BED_start_date-1992.5)*4+1:(BED_end_date-1992.5)*4+1,1); %quarterly
d_exit_q((BED_start_date-start_date)*4+1:(BED_end_date-start_date)*4+1,1) = BED_DATA2((BED_start_date-1992.5)*4+1:(BED_end_date-1992.5)*4+1,2); %quarterly
d_ue_q(1:(2007-start_date)*4+1) = SHIMER_DATA((start_date-1948)*4+1:(2007-1948)*4+1,1);
d_eu_q(1:(2007-start_date)*4+1) = SHIMER_DATA((start_date-1948)*4+1:(2007-1948)*4+1,2);
d_hi(int32((JOLTS_start_date-start_date)*12+1):int32((JOLTS_end_date-start_date)*12+1),1) = JOLTS_DATA(int32((JOLTS_start_date-2001)*12+2):int32((JOLTS_end_date-2001)*12+2),1); %monthly from Jan01 to Mar10
d_lf(int32((JOLTS_start_date-start_date)*12+1):int32((JOLTS_end_date-start_date)*12+1),1) = JOLTS_DATA(int32((JOLTS_start_date-2001)*12+2):int32((JOLTS_end_date-2001)*12+2),5); %monthly
d_qu(int32((JOLTS_start_date-start_date)*12+1):int32((JOLTS_end_date-start_date)*12+1),1) = JOLTS_DATA(int32((JOLTS_start_date-2001)*12+2):int32((JOLTS_end_date-2001)*12+2),7); %monthly
d_sp(int32((JOLTS_start_date-start_date)*12+1):int32((JOLTS_end_date-start_date)*12+1),1) = JOLTS_DATA(int32((JOLTS_start_date-2001)*12+2):int32((JOLTS_end_date-2001)*12+2),9); %monthly
d_v(int32((JOLTS_start_date-start_date)*12+1):int32((JOLTS_end_date-start_date)*12+1),1) = JOLTS_DATA(int32((JOLTS_start_date-2001)*12+2):int32((JOLTS_end_date-2001)*12+2),3); %monthly


% d_iqr_y = BLOOM_DATA(start_date-1972+1:end_date-1972+1,11); %yearly 2y
% d_std_y = BLOOM_DATA(start_date-1972+1:end_date-1972+1,8); %yearly 2y
d_iqr_y = BLOOM_DATA(start_date-1972+1:end_date-1972+1,5); %yearly 25y
d_std_y = BLOOM_DATA(start_date-1972+1:end_date-1972+1,2); %yearly 25y

% Create some quarterly series out from the monthly ones
d_labforce_q = averageM2Q(d_labforce);
d_unemp_q = averageM2Q(d_unemp);
d_hi_q = averageM2Q(d_hi)./d_labforce_q;
d_sp_q = averageM2Q(d_sp)./d_labforce_q;
d_qu_q = averageM2Q(d_qu)./d_labforce_q;
d_lf_q = averageM2Q(d_lf)./d_labforce_q;
d_v_q = averageM2Q(d_v)./d_labforce_q;

d_entry_q = d_entry_q ./ d_labforce_q;
d_exit_q = d_exit_q ./ d_labforce_q;
d_ee_q = (d_qu_q ./ (1-d_unemp_q))';

% Create an annual output measure to compute correlation with IQR
d_output_y=averageQ2Y(d_output_q);
d_logoutput_y=logdev(d_output_y,'Y');


% Compute log deviations
d_logoutput_dev = logdev(d_output_q,HP_PARAM);
d_logoutpp_dev = logdev(d_outpp_q,HP_PARAM);
d_logunemp_dev = logdev(d_unemp_q,HP_PARAM);

d_logue_dev=NaN*ones(length(start_date:.25:end_date_q),1);
d_logeu_dev=NaN*ones(length(start_date:.25:end_date_q),1);
d_logee_dev=NaN*ones(length(start_date:.25:end_date_q),1);
d_loghi_dev=NaN*ones(length(start_date:.25:end_date_q),1);
d_loglf_dev=NaN*ones(length(start_date:.25:end_date_q),1);
d_logsp_dev=NaN*ones(length(start_date:.25:end_date_q),1);
d_logqu_dev=NaN*ones(length(start_date:.25:end_date_q),1);
d_logv_dev=NaN*ones(length(start_date:.25:end_date_q),1);
d_logentry_dev=NaN*ones(length(start_date:.25:end_date_q),1);
d_logexit_dev=NaN*ones(length(start_date:.25:end_date_q),1);


d_logue_dev(1:(2007-start_date)*4+1) = logdev(d_ue_q(1:(2007-start_date)*4+1),'Q');
d_logeu_dev(1:(2007-start_date)*4+1) = logdev(d_eu_q(1:(2007-start_date)*4+1),'Q');
d_logee_dev((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1) = logdev(d_ee_q((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1),'Q');
d_logentry_dev((BED_start_date-start_date)*4+1:(BED_end_date-start_date)*4+1) = logdev(d_entry_q((BED_start_date-start_date)*4+1:(BED_end_date-start_date)*4+1),'Q');
d_logexit_dev((BED_start_date-start_date)*4+1:(BED_end_date-start_date)*4+1) = logdev(d_exit_q((BED_start_date-start_date)*4+1:(BED_end_date-start_date)*4+1),'Q');
d_loghi_dev((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1) = logdev(d_hi_q((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1),'Q');
d_logsp_dev((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1) = logdev(d_sp_q((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1),'Q');
d_logqu_dev((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1) = logdev(d_qu_q((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1),'Q');
d_loglf_dev((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1) = logdev(d_lf_q((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1),'Q');
d_logv_dev((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1) = logdev(d_v_q((JOLTS_start_date-start_date)*4+1:(end_date_q-start_date)*4+1),'Q');
d_logiqr_y = logdev(d_iqr_y,'Y');
d_logstd_y = logdev(d_std_y,'Y');



% -----------------------------------
% Compute empirical cross-correlation

start_date = 1; 

x = [d_logoutput_dev(start_date);d_logoutpp_dev(start_date);d_logunemp_dev(start_date);d_logv_dev(start_date);d_loghi_dev(start_date);d_logqu_dev(start_date);d_loglf_dev(start_date)];
N=length(x);
cov=zeros(N,N);
div=zeros(N,N);
for i=start_date:nb_periods    
    x = [d_logoutput_dev(i);d_logoutpp_dev(i);d_logunemp_dev(i);d_logv_dev(i);d_loghi_dev(i);d_logqu_dev(i);d_loglf_dev(i)];
    X=x*x';
    I=find(~isnan(X));
    cov(I) = cov(I) + X(I);
    div=div+~isnan(x*x');
end
cov = cov./(div-1);

stdev=zeros(1,N);
cor=zeros(N,N);
for i=1:N;
    stdev(i)=sqrt(cov(i,i));
    for j=1:N
        cor(i,j)=cov(i,j)/sqrt(cov(i,i)*cov(j,j));
    end
end

% ------------------
% Display statistics


format short
fprintf('----------------------------------------------------------------------\n');
fprintf('       DATA: Summary of the statistics (stdev(log), cor(log))\n');
fprintf('----------------------------------------------------------------------\n');
fprintf('       (1)       (2)       (3)       (4)       (5)       (6)       (7)\n');
fprintf('         Y       Y/L         u         v        hi        qu        lf\n');
disp(stdev);
fprintf('----------------------------------------------------------------------\n');
disp(cor);
fprintf('----------------------------------------------------------------------\n');
