% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% findss (y,s,param,vars,res): finds the steady-state distribution g(z,n) if y shocks are
% turned off and y given
%
% Instructions: - (y,s) current aggregate state of economy held constant (index)
% - 'param' is a structure of parameters for the model
% - 'vars' is a structure of variables created by 'initialize_vars(param)'
% - 'res' is a structure of results for the model from 'solve(param,vars)'
%
% ========================================================================


function [u1,g1,ss_error] = findss(y,s,param,vars,res)
TOL=1e-15;%1e-12;

g1=zeros(param.nz,param.nn);
g0=ones(param.nz,param.nn);
u1=1;
counter=0;

ss_error=false;
while (sum(sum((g1-g0).^2))/(param.nz*param.nn)>1e-15 && counter<200)
  g0=g1; 
  u0=u1;  
  [u1,g1,outpp,v,theta,UE,EU,EE,entry,exit,hi,sp,qu,lf,output,error]=distdyn(u0,g0,y,s,s,param,vars,res);    
  ss_error=ss_error|error;
  counter=counter+1;  
end

fprintf('Steady-state computed in %d iterations.\n',counter);