% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% impulse_breakdown.m: decompose the impulse responses to y and s shocks.
%
% Instructions: simply run 'impulse_breakdown()' without arguments
%
% -------------------------------------------------------------------------

function impulse_breakdown
% ---------------------
% Computing equilibrium 

% % Here I recompute the baseline equilibrium with the same dimensions but
% % larger grids in y and s to accomodate larger shocks... saved under
% % impulse.mat.

% fprintf('[-] Computing equilibrium...\n');
% 
% param = struct('A',1,'alpha',.85,'b',1.402502411917219,'beta',.996,'c',1.789395096004241,'ke',14.213281945105606,'kf',1.956256938229172,'lambda',0.366041621306308,...
%     'rho_y',0.990372641907069,'sigma_y',0.042251089970073,'rho_z',(.95)^(1/3),'sigma_z',0.532628971768815,...
%     'rho_s',0.98,'sigma_s',0.131668241312217,'cor_ys',-0.4,...
%     'gamma',1.59929,'m',1,...
%     'ny',21,'ns',15,'nz',15,'nn',50);  % these parameters correspond to calibration_full_010615 but with different grids
% 
% vars = initialize_vars(param,2,2,2,2,3,3);
% Y0_id=ceil(param.ny/2);
% S0_id=ceil(param.ns/2);
% Y0=vars.y_grid(Y0_id);
% S0=param.sigma_z;
% [res,aux,error]=solve(param,vars,[],[],'GE');
% % compute PE
% res_PE = res;
% res_PE.cost = res.cost(Y0_id + (S0_id-1)*param.ny)*ones(param.ny*param.ns,1);
% [res_PE,aux_PE,error]=solve(param,vars,res_PE,[],'PE');
% save('results/impulse.mat');
load('results/impulse.mat');

% ----
% Init


lag=5;
T=40+1+lag; % simulate T periods

Y0_id=ceil(param.ny/2);
S0_id=ceil(param.ns/2);
Y0=vars.y_grid(Y0_id);
S0=param.sigma_z;

% Init shocks
y=Y0*ones(2,T);
s=S0*ones(2,T);

y(2,lag+1)=Y0-0.01; % 1 percent shock to aggregate productivity (in logs)
s(1,lag+1)=S0*exp(0.05); % 5% shock to volatility


for t=lag+2:T
    y(:,t)=param.rho_y*y(:,t-1);
    s(:,t)=exp((1-param.rho_s)*log(param.sigma_z)+param.rho_s*log(s(:,t-1)));
end




% Init time series

nb_series=7;
output=zeros(nb_series,T);
outpp=zeros(nb_series,T);
v=zeros(nb_series,T);
unemp=zeros(nb_series,T);
hi=zeros(nb_series,T);
sp=zeros(nb_series,T);
qu=zeros(nb_series,T);
lf=zeros(nb_series,T);
entry=zeros(nb_series,T);
exit=zeros(nb_series,T);
massfirm=zeros(nb_series,T);
empl=zeros(nb_series,T);
net_empl=zeros(nb_series,T);

% Simulate
fprintf('[-] Computing steady state...');
[u0,g0,~,~,~,~,~,~,~,entry_GE]=findss_value(Y0,S0,param,vars,res); % find ss when y is constant equal to mean
[u0_PE,g0_PE,~,~,~,~,~,~,~,entry_PE]=findss_value(Y0,S0,param,vars,res_PE); % find ss when y is constant equal to mean

fprintf('\n[-] Beginning simulations...');
% first volatility shocks
fprintf('\n    No.1 ');
[unemp(1,:),~,~,outpp(1,:),v(1,:),~,~,~,~,entry(1,:),exit(1,:),hi(1,:),sp(1,:),qu(1,:),lf(1,:),output(1,:),~,~,~,massfirm(1,:),~,empl(1,:)] = simulate(y(1,:),s(1,:),param,vars,res,u0,g0,[],'free entry');
fprintf('\n    No.2 ');
[unemp(2,:),~,~,outpp(2,:),v(2,:),~,~,~,~,entry(2,:),exit(2,:),hi(2,:),sp(2,:),qu(2,:),lf(2,:),output(2,:),~,~,~,massfirm(2,:),~,empl(2,:)] = simulate(y(1,:),s(1,:),param,vars,res,u0,g0,S0*ones(1,T),'free entry');
fprintf('\n    No.3 ');
[unemp(3,:),~,~,outpp(3,:),v(3,:),~,~,~,~,entry(3,:),exit(3,:),hi(3,:),sp(3,:),qu(3,:),lf(3,:),output(3,:),~,~,~,massfirm(3,:),~,empl(3,:)] = simulate(y(1,:),s(1,:),param,vars,res,u0,g0,S0*ones(1,T),'fixed entry',entry_GE*ones(1,T));
fprintf('\n    No.4 ');
[unemp(4,:),~,~,outpp(4,:),v(4,:),~,~,~,~,entry(4,:),exit(4,:),hi(4,:),sp(4,:),qu(4,:),lf(4,:),output(4,:),~,~,~,massfirm(4,:),~,empl(4,:)] = simulate(y(1,:),s(1,:),param,vars,res_PE,u0_PE,g0_PE,S0*ones(1,T),'fixed entry',entry_PE*ones(1,T));
% now productivity shock
fprintf('\n    No.5 ');
[unemp(5,:),~,~,outpp(5,:),v(5,:),~,~,~,~,entry(5,:),exit(5,:),hi(5,:),sp(5,:),qu(5,:),lf(5,:),output(5,:),~,~,~,massfirm(5,:),~,empl(5,:)] = simulate(y(2,:),s(2,:),param,vars,res,u0,g0,[],'free entry');
fprintf('\n    No.6 ');
[unemp(6,:),~,~,outpp(6,:),v(6,:),~,~,~,~,entry(6,:),exit(6,:),hi(6,:),sp(6,:),qu(6,:),lf(6,:),output(6,:),~,~,~,massfirm(6,:),~,empl(6,:)] = simulate(y(2,:),s(2,:),param,vars,res,u0,g0,[],'fixed entry',entry_GE*ones(1,T));
fprintf('\n    No.7 ');
[unemp(7,:),~,~,outpp(7,:),v(7,:),~,~,~,~,entry(7,:),exit(7,:),hi(7,:),sp(7,:),qu(7,:),lf(7,:),output(7,:),~,~,~,massfirm(7,:),~,empl(7,:)] = simulate(y(2,:),s(2,:),param,vars,res_PE,u0_PE,g0_PE,[],'fixed entry',entry_PE*ones(1,T));
net_unemp=-(hi-qu)+lf;


% Plot

fprintf('\n[-] Plotting results...\n');
close all;

y=exp(y);

variables = {'hi','sp','qu','lf','entry','exit'};
labels = {'hirings','separations','quits','layoffs','entry','exit'};
% legend_labels_y = {'Full model','Constant entry','Constant entry + partial equilibrium'};
legend_labels_y = {'Constant entry + partial equilibrium','Constant entry (general equilibrium)','Full model (general equilibrium, free entry)'};
% legend_labels_v = {'Full model','Constant realized volatility','Constant realized volatility + constant entry','Constant realized volatility + constant entry + partial equilibrium'};
legend_labels_v = {'Constant realized volatility + constant entry + partial equilibrium','Constant realized volatility + constant entry (general equilibrium)','Constant realized volatility (general equilibrium, free entry)','Full model (general equilibrium, free entry, time-varying volatility)'};
% legend_labels_v = {'Constant realized volatility + constant entry + partial equilibrium'};
N=length(labels);

series=zeros(N,T,nb_series);

for i=1:nb_series
    for j=1:N
        data=eval(char(variables(j)));
        series(j,:,i)=data(i,:);
    end
end

display_series(series(:,:,1:4),'Volatility shock',labels,legend_labels_v,'graphs/impulse_v_breakdown.eps',lag);
display_series(series(:,:,5:7),'Productivity shock',labels,legend_labels_y,'graphs/impulse_y_breakdown.eps',lag);

end

function display_series(series,figtitle,labels,legend_labels,file,lag)
[N,T,nb]=size(series);

plots_per_row=3;
nbrows=ceil(N/plots_per_row);

nb_styles = 4;
linestyle = {'-',':','--','-.'};
linewidth = {1,1,1,1};
colorstyle = {[0 0 0],[0 .25 .75],[0 .5 .25],[.5 0 .25]};


hdl=figure;
set(hdl,'Units','inches','Position',[0,0,7.5,5],'PaperPositionMode','auto');
set(hdl,'Name',figtitle);
series_plot=zeros(nb,T);

margin = 0.05;
legend_h = .2;
axes_w_percent = .75;
axes_h_percent = .75;


for i=1:N
    x=mod(i-1,plots_per_row);
    y=floor((i-1)/plots_per_row);
    subplot('Position',[margin+(1-2*margin)/plots_per_row*(x+(1-axes_w_percent)/2) margin+legend_h+(1-2*margin-legend_h)/nbrows*(nbrows-1-y+(1-axes_h_percent)/2) axes_w_percent*(1-2*margin)/plots_per_row axes_h_percent*(1-2*margin-legend_h)/nbrows]);

    hold on;
    for j=nb:-1:1
        series_plot(j,:)=log(series(i,:,j))-log(series(i,1,j));
        style=1+mod(j-1,nb_styles);
        if strcmp(char(linestyle(style)),':')
            dashline(-lag:T-lag-1,series_plot(j,:),.5,.5,.5,.5,'Linewidth',cell2mat(linewidth(style)),'Color',cell2mat(colorstyle(style)));            
        else
            plot(-lag:T-lag-1,series_plot(j,:),char(linestyle(style)),'Linewidth',cell2mat(linewidth(style)),'Color',cell2mat(colorstyle(style)));
        end
    end
    title(sprintf('(%c) %s',97+i-1,char(labels(i))),'interpreter','latex');    

    set(gca,'Units','normalized','FontUnits','points','FontWeight','normal','FontSize',9,'FontName','Times');    
    xlim([-lag T-lag-1]);
    ymin = min(series_plot(:)); 
    ymax = max(series_plot(:));
    ymin=min(floor(ymin*100)/100,-0.01); % make sure the unit on the axis is in 1e-2, not less
    ymax=(floor(ymax*100)+1)/100;
    ylim([ymin-.05*(ymax-ymin) ymax+.05*(ymax-ymin)]);
    grid on;
    box on;
    hold off;
end

ld=legend(legend_labels,-1); % set the legend out of plot
set(ld,'Position',[margin margin 1-2*margin legend_h],'Box','off');
if nb>=2
    h=findobj(hdl,'DisplayName',ld.String{nb-1}); % fix the legend entry with dashline (not dotted otherwise)
    set(h,'LineStyle',':');
end

if ~isempty(file)
    print('-depsc2',file);
end
    
end