% ---------------------------------------------------------------------------
% logdev.m: compute log deviation from trend for a given series.
%           'option' can be either 'M', 'Q' or 'Y' for monthly, quarterly
%            or yearly frequency with HP filter, or 'linear' in case of
%            linear detrending. I added the 'Qbis' for an HP filter a 1e5
%

function [logseries_dev,series_t,error]=logdev(series,option)
[M,N]=size(series);
logseries_dev=NaN*ones(M,N);
series_t=zeros(M,N);

I=find(~isnan(series) & ~isinf(series));
i0=min(I);
i1=max(I);

error=false;
switch option
    case 'M' % monthly
        HP_param=14400;
        series_t(i0:i1) = hpfilter(series(i0:i1),HP_param);
    case 'Q' % quarterly
        HP_param=1600;
        series_t(i0:i1) = hpfilter(series(i0:i1),HP_param);
    case 'Qbis' % quarterly
        HP_param=1e5;
        series_t(i0:i1) = hpfilter(series(i0:i1),HP_param); 
    case 'Qfreq' % quarterly
        A=[ones(numel(series(i0:i1)),1) (1:numel(series(i0:i1)))'];
        [x,stdx,mse]=lscov(A, series(i0:i1));
        series_t(i0:i1) = A*x;     
        series(i0:i1)=bpass(series(i0:i1),6,32)+series_t(i0:i1);
    case 'Y' % yearly
        HP_param=100;
        series_t(i0:i1) = hpfilter(series(i0:i1),HP_param);
    case 'Yfreq' % quarterly
        A=[ones(numel(series(i0:i1)),1) (1:numel(series(i0:i1)))'];
        [x,stdx,mse]=lscov(A, series(i0:i1));
        series_t(i0:i1) = A*x;     
        series(i0:i1)=bpass(series(i0:i1),2,8)+series_t(i0:i1);
    case 'linear' % linear trend
        A=[ones(numel(series(i0:i1)),1) (1:numel(series(i0:i1)))'];
        [x,stdx,mse]=lscov(A, series(i0:i1));
        series_t(i0:i1) = A*x;        
    otherwise
        fprintf('%s.m:logdev(): unknown detrending procedure/frequency %s\n',mfilename,option);
        error=true;        
end

logseries_dev(i0:i1) = log(series(i0:i1)) - log(series_t(i0:i1));
end