% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% solveU(param,vars,cost): find the fixed point for unemployment valuation U(y,s)
% given 'cost' is the endogenous recruiting cost called 'kappa' in the model
%
% Instructions: - 'param' is a structure of parameters for the model
% - 'vars' is a structure of variables created by 'initialize_vars(param)'
% - 'cost' matrix of kappa(y,s)
%
% ========================================================================


function [U1,gxu,gtheta_xu,error] = solveU(param,vars,cost)

CV_tol = 1e-5; % tolerance for convergence
U0 = ones(param.ny*param.ns,1); % initialize vector of U(y,s) (put 1 to enter loop)
U1 = zeros(param.ny*param.ns,1);
counter=0;
error=0;
% cost=gather(cost);

% ------------------------------------------------------------
% Loop to find the fixed point solution for unemployed workers
%
while sum(abs(U1-U0))/(param.ny*param.ns)>CV_tol && counter<5000    
    U0=U1;

    gtheta_xu=((param.c./max(cost-U0,param.c)).^(-param.gamma/(1+param.gamma))-1).^(1/param.gamma); %solve for the optimal theta_xu analytically
    % note: if U0 > cost-c, then no more solution, no worker enters then
    % choose p(theta_xu)=0
    pmat=p(gtheta_xu,param);
    xmat=cost-param.c./q(gtheta_xu,param);
    U1 = param.b + param.beta*vars.pi_ys*(U0+pmat.*(xmat-U0)); % compute expectation Ui = b+beta(sum pi_ij*Uj)    
    counter=counter+1;    
end

if counter==5000
    fprintf('%s.m: max number of iterations reached\n',mfilename);
    error=1;
end

gxu=xmat; % return optimal decision for workers

