% =======================================================================
% UNCERTAINTY AND UNEMPLOYMENT
% by Edouard Schaal
% -----------------
% Replication files
%
% solvethetax(param,vars,cost,U): solves for the optimal theta_x chosen by firms 
% for quits when the domain is unconstrained (see numerical appendix)
%
% Instructions: - 'param' is a structure of parameters for the model
% - 'vars' is a structure of variables created by 'initialize_vars(param)'
% - 'cost' matrix of kappa(y,s)
% - 'U' is a matrix of value of unemployment over (y,s)
%
% ========================================================================

function theta_x_opt = solvethetax(param,vars,cost,U)

% We just need to solve for all (y,s):
% cost-U=c*[(1+theta.^gamma).^(1/gamma+1)-lambda_e*theta.^(gamma+1)]

theta_xl=zeros(param.ny*param.ns,1); % 0 is always a lower bound on the solution (since U<cost)
theta_xu=((gather(cost)-gather(U))/((1-param.lambda)*param.c)).^(1/(1+param.gamma)); % we know that K(theta)>(1-lambda_e).*c.*theta.^(1+gamma), which we can use to derive an upper bound

counter=0;
while(sum(abs(theta_xu-theta_xl))/(param.ny*param.ns)>1e-6 && counter<50)
    
    current_theta=(theta_xu+theta_xl)/2;
    val=param.c*((1+current_theta.^param.gamma).^(1/param.gamma+1)-param.lambda*current_theta.^(param.gamma+1));
    
    Iabove=val>cost-U;
    theta_xu(Iabove)=current_theta(Iabove);
    theta_xl(~Iabove)=current_theta(~Iabove);
    
    counter=counter+1;
end

theta_x_opt=current_theta;



